@@ -262,7 +262,7 @@ class TCPReceiveSocket(object):
                             print(received_data)
         :param tcp_ip: ip address to connect to.
         :param verbose: Whether or not to print errors and status messages.
-        :param as_server: Whether to run this socket as a server (default: True) or client. This needs to be opposite
+        :param as_server: Whether to run this socket as a server (default: False) or client. This needs to be opposite
                           whatever the SendSocket is configured to be.
         :param receive_as_raw: Whether or not the incoming data is just raw bytes or is a predefined format (JSON, NUMPY, HDF)
         :param receive_buffer_size: available buffer size in bytes when receiving messages
@@ -424,13 +424,23 @@ class TCPReceiveSocket(object):
                 while nbytes != -1:
                     try:
                         nbytes = self.connection.recv_into(view, self.receive_buffer_size - total_received - 1)
-                    except BlockingIOError as e:
                         if nbytes > 0 and nbytes % self.max_tcp_packet_size != 0:
-                            raise e
-                        elif nbytes == 0:
-                            continue
+                            total_received += nbytes
+                            raise BlockingIOError
+                    except Exception as e:
+                        if isinstance(e, error):
+                            self.is_connected = False
+                            nbytes=0
+                            break
+                        elif isinstance(e, BlockingIOError):
+                            if nbytes > 0 and nbytes % self.max_tcp_packet_size != 0:
+                                raise e
+                            elif nbytes == 0:
+                                continue
+                            else:
+                                continue
                         else:
-                            continue
+                            raise e
                     if nbytes == 0:
                         self.is_connected = False
                         break
